package VMOMI::DistributedVirtualSwitchNetworkResourceControlVersion;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
